.. _package_overview:

Package Overview
================

Introduction
------------

The core mission of pvlib-python is to provide open, reliable,
interoperable, and benchmark implementations of PV system models.

There are at least as many opinions about how to model PV systems as
there are modelers of PV systems, so pvlib-python provides several
modeling paradigms: functions, the Location/PVSystem classes, and the
ModelChain class. Read more about this in the :ref:`introtutorial`
section.


User extensions
---------------
There are many other ways to organize PV modeling code. We encourage you
to build on these paradigms and to share your experiences with the pvlib
community via issues and pull requests.


Getting support
---------------

pvlib usage questions can be asked on
`Stack Overflow  <http://stackoverflow.com>`_ and tagged with
the `pvlib <http://stackoverflow.com/questions/tagged/pvlib>`_ tag.

The `pvlib-python google group <https://groups.google.com/forum/#!forum/pvlib-python>`_
is used for discussing various topics of interest to the pvlib-python
community. We also make new version announcements on the google group.

If you suspect that you may have discovered a bug or if you'd like to
change something about pvlib, then please make an issue on our
`GitHub issues page <https://github.com/pvlib/pvlib-python/issues>`_ .


How do I contribute?
--------------------
We're so glad you asked! Please see :ref:`Contributing` for information and
instructions on how to contribute. We really appreciate it!


Credits
-------
The pvlib-python community thanks Sandia National Lab
for developing PVLIB Matlab and for supporting
Rob Andrews of Calama Consulting to port the library to Python.
Will Holmgren thanks the Department of Energy's Energy
Efficiency and Renewable Energy Postdoctoral Fellowship Program
(2014-2016), the University of Arizona Institute for Energy Solutions (2017-2018),
and the DOE Solar Forecasting 2 program (2018).
The pvlib-python maintainers thank all of pvlib's contributors of issues
and especially pull requests.
The pvlib-python community thanks all of the
maintainers and contributors to the PyData stack.
